@@ -54,6 +54,7 @@
 #include "headers.h"
 #include "util.h"
 #include "delay.h"
+#include "Thread.h"
 #include <math.h>
 
 #define MILLION 1000000
@@ -98,7 +99,11 @@ void delay_loop(unsigned long usec)
     struct timespec res;
     res.tv_sec = usec/MILLION;
     res.tv_nsec = (usec * 1000) % BILLION;
+  #ifndef WIN32
     clock_nanosleep(CLOCK_MONOTONIC, 0, &res, NULL);
+  #else
+    clock_nanosleep(0, 0, &res, NULL);
+  #endif
   }
 #else
   #ifdef HAVE_KALMAN
@@ -113,6 +118,73 @@ void delay_loop(unsigned long usec)
 #endif
 }
 
+int clock_usleep (struct timeval *request) {
+    int rc = 0;
+#if HAVE_THREAD_DEBUG
+    thread_debug("Thread called clock_usleep() until %ld.%ld", request->tv_sec, request->tv_usec);
+#endif
+#ifdef HAVE_CLOCK_NANOSLEEP
+    struct timespec tmp;
+    tmp.tv_sec = request->tv_sec;
+    tmp.tv_nsec = request->tv_usec * 1000;
+
+// Cygwin systems have an issue with CLOCK_MONOTONIC
+#if defined(CLOCK_MONOTONIC) && !defined(WIN32)
+    rc = clock_nanosleep(CLOCK_MONOTONIC, 0, &tmp, NULL);
+#else
+    rc = clock_nanosleep(0, 0, &tmp, NULL);
+#endif
+    if (rc) {
+	fprintf(stderr, "failed clock_nanosleep()=%d\n", rc);
+    }
+#else
+    struct timeval now;
+    struct timeval next = *request;
+#ifdef HAVE_CLOCK_GETTIME
+    struct timespec t1;
+    clock_gettime(CLOCK_REALTIME, &t1);
+    now.tv_sec  = t1.tv_sec;
+    now.tv_usec = t1.tv_nsec / 1000;
+#else
+    gettimeofday(&now, NULL);
+#endif
+    double delta_usecs;
+    if ((delta_usecs = TimeDifference(next, now)) > 0.0) {
+	delay_loop(delta_usecs);
+    }
+#endif
+    return rc;
+}
+
+int clock_usleep_abstime (struct timeval *request) {
+    int rc = 0;
+#if defined(HAVE_CLOCK_NANOSLEEP) && defined(TIMER_ABSTIME) && !defined(WIN32)
+    struct timespec tmp;
+    tmp.tv_sec = request->tv_sec;
+    tmp.tv_nsec = request->tv_usec * 1000;
+    rc = clock_nanosleep(CLOCK_REALTIME, TIMER_ABSTIME, &tmp, NULL);
+    if (rc) {
+	fprintf(stderr, "failed clock_nanosleep()=%d\n", rc);
+    }
+#else
+    struct timeval now;
+    struct timeval next = *request;
+#ifdef HAVE_CLOCK_GETTIME
+    struct timespec t1;
+    clock_gettime(CLOCK_REALTIME, &t1);
+    now.tv_sec  = t1.tv_sec;
+    now.tv_usec = t1.tv_nsec / 1000;
+#else
+    gettimeofday(&now, NULL);
+#endif
+    double delta_usecs;
+    if ((delta_usecs = (1e6 * TimeDifference(next, now))) > 0.0) {
+	delay_loop(delta_usecs);
+    }
+#endif
+    return rc;
+}
+
 #ifdef HAVE_NANOSLEEP
 // Can use the nanosleep syscall suspending the thread
 void delay_nanosleep (unsigned long usec) {
@@ -239,7 +311,7 @@ void delay_kalman (unsigned long usec) {
     }
     // Compute the delay error in units of nanoseconds
     // and cast to type double
-    err = (double) (timespec_diff(t2, t1) - (usec * 1000));
+    err = (timespec_diff(t2, t1) - (usec * 1000));
     // printf("req: %ld adj: %f err: %.5f (ns)\n", usec, nsec_adjusted, kalmanerr.x);
     kalman_update(&kalmanerr, err);
 }
