@@ -68,7 +68,7 @@ extern "C" {
 #endif
 
 
-#if   defined( HAVE_POSIX_THREAD )
+#if   defined(HAVE_POSIX_THREAD)
 
 /* Definitions for Posix Threads (pthreads) */
 #include <pthread.h>
@@ -77,7 +77,7 @@ typedef pthread_t nthread_t;
 
 #define HAVE_THREAD 1
 
-#elif defined( HAVE_WIN32_THREAD )
+#elif defined(HAVE_WIN32_THREAD)
 
 /* Definitions for Win32 NT Threads */
 typedef DWORD nthread_t;
@@ -107,67 +107,68 @@ extern Mutex thread_debug_mutex;
 extern Mutex packetringdebug_mutex;
 #endif
 // initialize or destroy the thread subsystem
-void thread_init( );
-void thread_destroy( );
+void thread_init();
+void thread_destroy();
 
 // start or stop a thread executing
-void thread_start_all( struct thread_Settings* thread );
-void thread_start( struct thread_Settings* thread );
-void thread_stop( struct thread_Settings* thread );
+void thread_start_all(struct thread_Settings* thread);
+void thread_start(struct thread_Settings* thread);
+void thread_stop(struct thread_Settings* thread);
 
 /* wait for this or all threads to complete */
-void thread_joinall( void );
-int thread_numuserthreads( void );
-int thread_numtrafficthreads( void );
+void thread_joinall(void);
+int thread_numuserthreads(void);
+int thread_numtrafficthreads(void);
 
 // set a thread to be ignorable, so joinall won't wait on it
-void thread_setignore( void );
-void thread_unsetignore( void );
+void thread_setignore(void);
+void thread_unsetignore(void);
 
 // Used for threads that may never terminate (ie Listener Thread)
-void thread_register_nonterm( void );
-void thread_unregister_nonterm( void );
-int thread_release_nonterm( int force );
+void thread_register_nonterm(void);
+void thread_unregister_nonterm(void);
+int thread_release_nonterm(int interrupt);
 
 /* -------------------------------------------------------------------
  * Return the current thread's ID.
  * ------------------------------------------------------------------- */
-#if   defined( HAVE_POSIX_THREAD )
+#if   defined(HAVE_POSIX_THREAD)
 #define thread_getid() pthread_self()
-#elif defined( HAVE_WIN32_THREAD )
+#elif defined(HAVE_WIN32_THREAD)
 #define thread_getid() GetCurrentThreadId()
 #else
 #define thread_getid() 0
 #endif
 
-int thread_equalid( nthread_t inLeft, nthread_t inRight );
+int thread_equalid(nthread_t inLeft, nthread_t inRight);
 
-nthread_t thread_zeroid( void );
+nthread_t thread_zeroid(void);
 
-#if   defined( HAVE_WIN32_THREAD )
-DWORD WINAPI thread_run_wrapper( void* paramPtr );
+#if   defined(HAVE_WIN32_THREAD)
+DWORD WINAPI thread_run_wrapper(void* paramPtr);
 #else
-void*thread_run_wrapper( void* paramPtr );
+void*thread_run_wrapper(void* paramPtr);
 #endif
 
 #if HAVE_SCHED_SETSCHEDULER
 void thread_setscheduler(struct thread_Settings *thread);
 #endif
 
-void thread_rest ( void );
+void thread_rest (void);
 
 // defined in launch.cpp
-void server_spawn( struct thread_Settings* thread );
-void client_spawn( struct thread_Settings* thread );
-void client_init( struct thread_Settings* clients );
-void listener_spawn( struct thread_Settings* thread );
-void writeack_server_spawn( struct thread_Settings* thread );
-void writeack_client_spawn( struct thread_Settings* thread );
+void server_spawn(struct thread_Settings* thread);
+void client_spawn(struct thread_Settings* thread);
+void client_init(struct thread_Settings* clients);
+void listener_spawn(struct thread_Settings* thread);
+void listeners_init(struct thread_Settings* listeners);
+void writeack_server_spawn(struct thread_Settings* thread);
+void writeack_client_spawn(struct thread_Settings* thread);
 int fullduplex_start_barrier(struct BarrierMutex *barrier);
 int fullduplex_stop_barrier(struct BarrierMutex *barrier);
 
 // defined in reporter.c
-void reporter_spawn( struct thread_Settings* thread );
+void reporter_spawn(struct thread_Settings* thread);
 
 #ifdef __cplusplus
 } /* end extern "C" */
