@@ -69,6 +69,8 @@ struct ReportStruct {
     int l2errors;
     int l2len;
     int expected_l2len;
+    // isochStartTime is overloaded: first write timestamp of the frame or burst w/trip-times or very first read w/o trip-times
+    // reporter calculation will compute latency accordingly
     struct timeval isochStartTime;
     intmax_t prevframeID;
     intmax_t frameID;
@@ -80,6 +82,7 @@ struct ReportStruct {
     long write_time;
     struct timeval sentTimeRX;
     struct timeval sentTimeTX;
+    struct timeval BBTime0;
     struct iperf_tcpstats tcpstats;
 };
 
