@@ -70,8 +70,6 @@ extern int sInterupted;
 int setsock_tcp_windowsize(int inSock, int inTCPWin, int inSend);
 int getsock_tcp_windowsize(int inSock, int inSend);
 
-void setsock_tcp_mss(int inSock, int inMSS);
-int  getsock_tcp_mss(int inSock);
 bool setsock_blocking(int fd, bool blocking);
 #if HAVE_DECL_TCP_WINDOW_CLAMP
 int  getsock_tcp_windowclamp(int inSock);
@@ -85,6 +83,7 @@ int recvn(int inSock, char *outBuf, int inLen, int flags);
 int writen(int inSock, const void *inBuf, int inLen, int *count);
 
 void disarm_itimer(void);
+int set_itimer(int);
 /* -------------------------------------------------------------------
  * signal handlers
  * signal.c
@@ -193,8 +192,11 @@ void byte_snprintf(char* outString, int inLen, double inNum, char inFormat);
 
 #define TimeZero(timeval) ((timeval.tv_sec == 0) && (timeval.tv_usec == 0))
 
-#define TimeDifference(left, right) (left.tv_sec  - right.tv_sec) +   \
-        (left.tv_usec - right.tv_usec) / ((double) rMillion)
+#define TimeDifference(left, right) ((left.tv_sec  - right.tv_sec) +	\
+				     (left.tv_usec - right.tv_usec) / ((double) rMillion))
+
+#define TimeDifferenceUsec(left, right)  ((1e6 * (left.tv_sec  - right.tv_sec)) + \
+					  (double) (left.tv_usec - right.tv_usec))
 
 #define TimeDouble(timeval) (timeval.tv_sec + timeval.tv_usec / ((double) rMillion))
 
