@@ -220,7 +220,9 @@ static void clientside_client_fullduplex (struct thread_Settings *thread, Client
     struct thread_Settings *reverse_client = NULL;
     setTransferID(thread, 0);
     SockAddr_remoteAddr(thread);
-    thread->mFullDuplexReport = InitSumReport(thread, -1, 1);
+    if (!isBounceBack(thread)) {
+        thread->mFullDuplexReport = InitSumReport(thread, -1, 1);
+    }
     Settings_Copy(thread, &reverse_client, 0);
     if ((thread->mThreads > 1) || isSumOnly(thread) || \
 	(!(thread->mThreads > 1) && !isEnhanced(thread))) {
@@ -394,15 +396,32 @@ void client_init(struct thread_Settings *clients) {
 	itr->runNow = next;
 	itr = next;
     }
-    if (isBounceBack(clients) && isCongest(clients)) {
-	Settings_Copy(clients, &next, 1);
-	if (next != NULL) {
-	    setFullDuplex(next);
-	    unsetBounceBack(next);
-	    unsetEnhanced(next);
-	    next->mTOS = 0;
-	    itr->runNow = next;
-	    itr = next;
+    if (isBounceBack(clients) && (isWorkingLoadUp(clients) || isWorkingLoadDown(clients))) {
+	int bbwlthreads = (clients->mBounceBackCongestThreads == 0) ? 1 : clients->mBounceBackCongestThreads;
+	while (bbwlthreads--) {
+	    Settings_Copy(clients, &next, 1);
+	    if (next != NULL) {
+		unsetBounceBack(next);
+		unsetPeriodicBurst(next);
+		unsetTxHoldback(next); // don't delay working load threads
+		next->mTOS = 0; // disable any QoS on the congestion stream
+		if (isWorkingLoadUp(clients) && isWorkingLoadDown(clients)) {
+		    setFullDuplex(next);
+		} else if (isWorkingLoadDown(clients)) {
+		    setReverse(next);
+		}
+		if (isBounceBack(clients) && (clients->mBounceBackCongestThreads > 1)) {
+		    Iperf_push_host(clients);
+		}
+		// Bump the bounceback time to include the delay time
+		if (next->txholdback_timer.tv_sec || next->txholdback_timer.tv_usec) {
+		    // mAmount units are 10 ms
+		    next->mAmount += (next->txholdback_timer.tv_sec * 100);
+		    next->mAmount += (next->txholdback_timer.tv_usec / 10000);
+		}
+		itr->runNow = next;
+		itr = next;
+	    }
 	}
     }
 #else
