@@ -896,23 +896,46 @@ int Listener::udp_accept (thread_Settings *server) {
     // Preset the server socket to INVALID, hang recvfrom on the Listener's socket
     // The INVALID socket is used to keep the while loop going
     server->mSock = INVALID_SOCKET;
-    nread = recvfrom(ListenSocket, server->mBuf, server->mBufLen, 0, \
-		     reinterpret_cast<struct sockaddr*>(&server->peer), &server->size_peer);
-    Timestamp now;
-    server->accept_time.tv_sec = now.getSecs();
-    server->accept_time.tv_usec = now.getUsecs();
-
-#if HAVE_THREAD_DEBUG
-    {
-	char tmpaddr[200];
-	size_t len=200;
-	unsigned short port = SockAddr_getPort(&server->peer);
-	SockAddr_getHostAddress(&server->peer, tmpaddr, len);
-	thread_debug("rcvfrom peer: %s port %d len=%d", tmpaddr, port, nread);
-    }
-#endif
+    intmax_t packetID;
+    struct UDP_datagram* mBuf_UDP  = reinterpret_cast<struct UDP_datagram*>(server->mBuf);
+    // Look for a UDP packet with a postive seq no while draining any neg seq no packets
+    // The UDP client traffic thread uses negative seq numbers to indicate to the server that
+    // traffic is over. Some of those "final" packets can be in the stack/network pipeline after the server
+    // thread has ended and closed its reporting. The Listener will now receive them as if they are
+    // "first packets. Any "new" packets seen by the Listener causes a new "udp accept"
+    // per UDP's stateless design. So, in the case of negative seq nos, we know that this is
+    // most likely not a new client thread requiring a new server thread, but remnants of an
+    // old one that already ended. Hence, the Listener should ignore "first packets" when
+    // they have negative seq numbers.
+    do {
+	packetID = 0;
+	nread = recvfrom(ListenSocket, server->mBuf, server->mBufLen, 0, \
+			 reinterpret_cast<struct sockaddr*>(&server->peer), &server->size_peer);
+	if (nread > 0) {
+	    // filter and ignore negative sequence numbers, these can be heldover from a previous run
+	    if (isSeqNo64b(mSettings)) {
+		// New client - Signed PacketID packed into unsigned id2,id
+		packetID = (static_cast<uint32_t>(ntohl(mBuf_UDP->id))) | (static_cast<uintmax_t>(ntohl(mBuf_UDP->id2)) << 32);
+	    } else {
+		// Old client - Signed PacketID in Signed id
+		packetID = static_cast<int32_t>(ntohl(mBuf_UDP->id));
+	    }
+	}
+    } while ((nread > 0) && (packetID < 0) && !sInterupted);
     FAIL_errno(nread == SOCKET_ERROR, "recvfrom", mSettings);
-    if (!(nread < 0) && !sInterupted) {
+    if ((nread > 0) && !sInterupted) {
+	Timestamp now;
+	server->accept_time.tv_sec = now.getSecs();
+	server->accept_time.tv_usec = now.getUsecs();
+#if HAVE_THREAD_DEBUG
+	{
+	    char tmpaddr[200];
+	    size_t len=200;
+	    unsigned short port = SockAddr_getPort(&server->peer);
+	    SockAddr_getHostAddress(&server->peer, tmpaddr, len);
+	    thread_debug("rcvfrom peer: %s port %d len=%d", tmpaddr, port, nread);
+	}
+#endif
 	// Handle connection for UDP sockets
 	int gid = Iperf_push_host_port_conditional(server);
 #if HAVE_THREAD_DEBUG
@@ -1196,6 +1219,9 @@ bool Listener::apply_client_settings_tcp (thread_Settings *server) {
 	struct client_tcp_testhdr *hdr = reinterpret_cast<struct client_tcp_testhdr *>(server->mBuf);
 	uint32_t flags = ntohl(hdr->base.flags);
 	if (flags & HEADER_BOUNCEBACK) {
+	    if (!isServerModeTime(server)) {
+		unsetModeTime(server);
+	    }
 	    struct bounceback_hdr *bbhdr = reinterpret_cast<struct bounceback_hdr *>(server->mBuf);
 	    setBounceBack(server);
 	    nread = recvn(server->mSock, readptr, sizeof(struct bounceback_hdr), 0);
