@@ -89,6 +89,7 @@ static int HEADING_FLAG(report_bw_jitter_loss_enhanced_isoch_triptime) = 0;
 static int HEADING_FLAG(report_sumcnt_bw_jitter_loss) = 0;
 static int HEADING_FLAG(report_burst_read_tcp) = 0;
 static int HEADING_FLAG(report_burst_write_tcp) = 0;
+static int HEADING_FLAG(report_bw_isoch_enhanced_netpwr) = 0;
 
 void reporter_default_heading_flags (int flag) {
     HEADING_FLAG(report_bw) = flag;
@@ -117,6 +118,7 @@ void reporter_default_heading_flags (int flag) {
     HEADING_FLAG(report_sumcnt_bw_pps_enhanced) = flag;
     HEADING_FLAG(report_burst_read_tcp) = flag;
     HEADING_FLAG(report_burst_write_tcp) = flag;
+    HEADING_FLAG(report_bw_isoch_enhanced_netpwr) = flag;
 }
 static inline void _print_stats_common (struct TransferInfo *stats) {
     assert(stats!=NULL);
@@ -151,7 +153,7 @@ static inline void _output_outoforder(struct TransferInfo *stats) {
 //  lambda the arrival rate and W is the processing time
 //
 #define LLAW_LOWERBOUNDS -1e7
-static inline void set_llawbuf(double lambda, double meantransit, struct TransferInfo *stats) {
+static inline void set_llawbuf(double lambda, double meantransit) {
     double L  = lambda * meantransit;
     if (L < LLAW_LOWERBOUNDS) {
 	strcpy(llaw_buf, "OBL");
@@ -161,7 +163,7 @@ static inline void set_llawbuf(double lambda, double meantransit, struct Transfe
 	llaw_buf[sizeof(llaw_buf)-1] = '\0';
     }
 }
-static inline void set_llawbuf_udp (int lambda, double meantransit, double variance, struct TransferInfo *stats) {
+static inline void set_llawbuf_udp (int lambda, double meantransit, double variance, intmax_t pktcnt) {
     int Lvar = 0;
     int L  = round(lambda * meantransit);
     if (variance > 0.0) {
@@ -169,7 +171,19 @@ static inline void set_llawbuf_udp (int lambda, double meantransit, double varia
     } else {
 	Lvar = 0;
     }
-    snprintf(llaw_buf, sizeof(llaw_buf), "%" PRIdMAX "/%d(%d) pkts", stats->cntIPG, L, Lvar);
+    snprintf(llaw_buf, sizeof(llaw_buf), "%" PRIdMAX "/%d(%d) pkts", pktcnt, L, Lvar);
+    llaw_buf[sizeof(llaw_buf) - 1] = '\0';
+}
+
+static inline void set_llawbuf_frames (int lambda, double meantransit, double variance, intmax_t framecnt) {
+    int Lvar = 0;
+    int L  = round(lambda * meantransit);
+    if (variance > 0.0) {
+	Lvar  = round(lambda * variance);
+    } else {
+	Lvar = 0;
+    }
+    snprintf(llaw_buf, sizeof(llaw_buf), "%" PRIdMAX "/%d(%d) frames", framecnt, L, Lvar);
     llaw_buf[sizeof(llaw_buf) - 1] = '\0';
 }
 
@@ -237,11 +251,11 @@ void tcp_output_read_enhanced (struct TransferInfo *stats) {
 	   stats->sock_callstats.read.bins[7]);
     fflush(stdout);
 }
-void tcp_output_read_enhanced_triptime (struct TransferInfo *stats) {
+void tcp_output_read_triptime (struct TransferInfo *stats) {
     HEADING_PRINT_COND(report_bw_read_enhanced_netpwr);
     double meantransit = (stats->transit.current.cnt > 0) ? (stats->transit.current.sum / stats->transit.current.cnt) : 0;
     double lambda = (stats->IPGsum > 0.0) ? ((double)stats->cntBytes / stats->IPGsum) : 0.0;
-    set_llawbuf(lambda, meantransit, stats);
+    set_llawbuf(lambda, meantransit);
     _print_stats_common(stats);
     if (stats->cntBytes) {
         set_netpowerbuf(meantransit, stats);
@@ -293,6 +307,59 @@ void tcp_output_read_enhanced_triptime (struct TransferInfo *stats) {
     }
     fflush(stdout);
 }
+void tcp_output_read_enhanced_isoch (struct TransferInfo *stats) {
+    HEADING_PRINT_COND(report_bw_isoch_enhanced_netpwr);
+    double meantransit = (stats->transit.current.cnt > 0) ? (stats->transit.current.sum / stats->transit.current.cnt) : 0;
+    _print_stats_common(stats);
+    if (stats->cntBytes) {
+        set_netpowerbuf(meantransit, stats);
+	printf(report_bw_isoch_enhanced_netpwr_format,
+	       stats->common->transferIDStr, stats->ts.iStart, stats->ts.iEnd,
+	       outbuffer, outbufferext,
+	       (meantransit * 1e3),
+	       (stats->transit.current.cnt < 2) ? 0 : stats->transit.current.min * 1e3,
+	       (stats->transit.current.cnt < 2) ? 0 : stats->transit.current.max * 1e3,
+	       (stats->transit.current.cnt < 2) ? 0 : 1e3 * (sqrt(stats->transit.current.m2 / (stats->transit.current.cnt - 1))),
+	       stats->transit.current.cnt,
+	       stats->transit.current.cnt ? (long) ((double)stats->cntBytes / (double) stats->transit.current.cnt) : 0,
+	       netpower_buf,
+	       stats->sock_callstats.read.cntRead,
+	       stats->sock_callstats.read.bins[0],
+	       stats->sock_callstats.read.bins[1],
+	       stats->sock_callstats.read.bins[2],
+	       stats->sock_callstats.read.bins[3],
+	       stats->sock_callstats.read.bins[4],
+	       stats->sock_callstats.read.bins[5],
+	       stats->sock_callstats.read.bins[6],
+	       stats->sock_callstats.read.bins[7]);
+    } else {
+        set_netpowerbuf(meantransit, stats);
+	printf(report_bw_isoch_enhanced_netpwr_format,
+	       stats->common->transferIDStr, stats->ts.iStart, stats->ts.iEnd,
+	       outbuffer, outbufferext,
+	       (meantransit * 1e3),
+	       stats->transit.current.min * 1e3,
+	       stats->transit.current.max * 1e3,
+	       (stats->transit.current.cnt < 2) ? 0 : 1e3 * (sqrt(stats->transit.current.m2 / (stats->transit.current.cnt - 1))),
+	       stats->transit.current.cnt,
+	       stats->transit.current.cnt ? (long) ((double)stats->cntBytes / (double) stats->transit.current.cnt) : 0,
+	       netpower_buf,
+	       stats->sock_callstats.read.cntRead,
+	       stats->sock_callstats.read.bins[0],
+	       stats->sock_callstats.read.bins[1],
+	       stats->sock_callstats.read.bins[2],
+	       stats->sock_callstats.read.bins[3],
+	       stats->sock_callstats.read.bins[4],
+	       stats->sock_callstats.read.bins[5],
+	       stats->sock_callstats.read.bins[6],
+	       stats->sock_callstats.read.bins[7]);
+    }
+    if (stats->framelatency_histogram) {
+	histogram_print(stats->framelatency_histogram, stats->ts.iStart, stats->ts.iEnd);
+    }
+    fflush(stdout);
+}
+
 void tcp_output_frame_read (struct TransferInfo *stats) {
     HEADING_PRINT_COND(report_frame_tcp_enhanced);
     _print_stats_common(stats);
@@ -367,37 +434,43 @@ void tcp_output_write (struct TransferInfo *stats) {
 void tcp_output_write_bb (struct TransferInfo *stats) {
     HEADING_PRINT_COND(report_client_bb_bw);
     _print_stats_common(stats);
+    char rps_string[40];
     if (stats->final) {
-	int cnt_sec = (stats->bbrtt.total.cnt > 0) ? ((int) ((double) stats->bbrtt.total.cnt / (stats->ts.iEnd - stats->ts.iStart))) : 0;
+        double rps = ((stats->fBBrunning > 0) && (stats->bbrtt.total.cnt > 0)) ? ((double) stats->bbrtt.total.cnt / stats->fBBrunning) : 0;
+	if (rps < 10)
+	    snprintf(rps_string, sizeof(rps_string), "%0.1f", rps);
+	else
+	    snprintf(rps_string, sizeof(rps_string), "%0.0f", rps);
+	rps_string[sizeof(rps_string) - 1] = '\0';
+
 #if HAVE_TCP_STATS
 	printf(report_client_bb_bw_format, stats->common->transferIDStr,
 	       stats->ts.iStart, stats->ts.iEnd,
 	       outbuffer, outbufferext,
 	       stats->bbrtt.total.cnt,
-	       cnt_sec,
 	       (stats->bbrtt.total.mean * 1e3),
 	       (stats->bbrtt.total.cnt < 2) ? 0 : (stats->bbrtt.total.min * 1e3),
 	       (stats->bbrtt.total.cnt < 2) ? 0 : (stats->bbrtt.total.max * 1e3),
 	       (stats->bbrtt.total.cnt < 2) ? 0 : 1e3 * (sqrt(stats->bbrtt.total.m2 / (stats->bbrtt.total.cnt - 1))),
 	       stats->sock_callstats.write.tcpstats.retry,
 	       stats->sock_callstats.write.tcpstats.cwnd,
-	       stats->sock_callstats.write.tcpstats.rtt);
+	       stats->sock_callstats.write.tcpstats.rtt,
+	       rps_string);
 #else
 	printf(report_client_bb_bw_format, stats->common->transferIDStr,
 	       stats->ts.iStart, stats->ts.iEnd,
 	       outbuffer, outbufferext,
 	       stats->bbrtt.total.cnt,
-	       cnt_sec,
 	       (stats->bbrtt.total.mean * 1e3),
 	       (stats->bbrtt.total.cnt < 2) ? 0 : (stats->bbrtt.total.min * 1e3),
 	       (stats->bbrtt.total.cnt < 2) ? 0 : (stats->bbrtt.total.max * 1e3),
-	       (stats->bbrtt.total.cnt < 2) ? 0 : 1e3 * (sqrt(stats->bbrtt.total.m2 / (stats->bbrtt.total.cnt - 1))));
+	       (stats->bbrtt.total.cnt < 2) ? 0 : 1e3 * (sqrt(stats->bbrtt.total.m2 / (stats->bbrtt.total.cnt - 1))),
+	       rps_string);
 #endif
 	if (isTripTime(stats->common)) {
 	    printf(report_client_bb_bw_triptime_format, stats->common->transferIDStr,
 		   stats->ts.iStart, stats->ts.iEnd,
 		   stats->bbowdto.total.cnt,
-		   cnt_sec,
 		   (stats->bbowdto.total.mean * 1e3),
 		   (stats->bbowdto.total.cnt < 2) ? 0 : (stats->bbowdto.total.min * 1e3),
 		   (stats->bbowdto.total.cnt < 2) ? 0 : (stats->bbowdto.total.max * 1e3),
@@ -409,36 +482,43 @@ void tcp_output_write_bb (struct TransferInfo *stats) {
 		   (stats->bbasym.total.mean * 1e3),
 		   (stats->bbasym.total.cnt < 2) ? 0 : (stats->bbasym.total.min * 1e3),
 		   (stats->bbasym.total.cnt < 2) ? 0 : (stats->bbasym.total.max * 1e3),
-		   (stats->bbasym.total.cnt < 2) ? 0 : 1e3 * (sqrt(stats->bbasym.total.m2 / (stats->bbasym.total.cnt - 1))));
+		   (stats->bbasym.total.cnt < 2) ? 0 : 1e3 * (sqrt(stats->bbasym.total.m2 / (stats->bbasym.total.cnt - 1))),
+		   rps_string);
 	}
 	if (stats->bbrtt_histogram) {
-	  histogram_print(stats->bbrtt_histogram, stats->ts.iStart, stats->ts.iEnd);
+	    histogram_print(stats->bbrtt_histogram, stats->ts.iStart, stats->ts.iEnd);
 	}
     } else {
-	int cnt_sec = (stats->bbrtt.total.cnt > 0) ? ((int) ((double) stats->bbrtt.current.cnt / (stats->ts.iEnd - stats->ts.iStart))) : 0;
+	double rps = ((stats->bbrtt.current.cnt > 0) && (stats->iBBrunning > 0)) ? ((double) stats->bbrtt.current.cnt / stats->iBBrunning) : 0;
+	if (rps < 10)
+	    snprintf(rps_string, sizeof(rps_string), "%0.1f", rps);
+	else
+	    snprintf(rps_string, sizeof(rps_string), "%0.0f", rps);
+	rps_string[sizeof(rps_string) - 1] = '\0';
+
 #if HAVE_TCP_STATS
 	printf(report_client_bb_bw_format, stats->common->transferIDStr,
 	       stats->ts.iStart, stats->ts.iEnd,
 	       outbuffer, outbufferext,
 	       stats->bbrtt.current.cnt,
-	       cnt_sec,
 	       (stats->bbrtt.current.mean * 1e3),
 	       (stats->bbrtt.current.cnt < 2) ? 0 : (stats->bbrtt.current.min * 1e3),
 	       (stats->bbrtt.current.cnt < 2) ? 0 : (stats->bbrtt.current.max * 1e3),
 	       (stats->bbrtt.current.cnt < 2) ? 0 : 1e3 * (sqrt(stats->bbrtt.current.m2 / (stats->bbrtt.current.cnt - 1))),
 	       stats->sock_callstats.write.tcpstats.retry,
 	       stats->sock_callstats.write.tcpstats.cwnd,
-	       stats->sock_callstats.write.tcpstats.rtt);
+	       stats->sock_callstats.write.tcpstats.rtt,
+	       rps_string);
 #else
 	printf(report_client_bb_bw_format, stats->common->transferIDStr,
 	       stats->ts.iStart, stats->ts.iEnd,
 	       outbuffer, outbufferext,
 	       stats->bbrtt.current.cnt,
-	       cnt_sec,
 	       (stats->bbrtt.current.mean * 1e3),
 	       (stats->bbrtt.current.cnt < 2) ? 0 : (stats->bbrtt.current.min * 1e3),
 	       (stats->bbrtt.current.cnt < 2) ? 0 : (stats->bbrtt.current.max * 1e3),
-	       (stats->bbrtt.current.cnt < 2) ? 0 : 1e3 * (sqrt(stats->bbrtt.current.m2 / (stats->bbrtt.current.cnt - 1))));
+	       (stats->bbrtt.current.cnt < 2) ? 0 : 1e3 * (sqrt(stats->bbrtt.current.m2 / (stats->bbrtt.current.cnt - 1))),
+	       rps_string);
 #endif
     }
     fflush(stdout);
@@ -651,7 +731,7 @@ void udp_output_read (struct TransferInfo *stats) {
     fflush(stdout);
 }
 
-void udp_output_read_enhanced_triptime (struct TransferInfo *stats) {
+void udp_output_read_triptime (struct TransferInfo *stats) {
     HEADING_PRINT_COND(report_bw_jitter_loss_enhanced_triptime);
     _print_stats_common(stats);
 
@@ -676,7 +756,7 @@ void udp_output_read_enhanced_triptime (struct TransferInfo *stats) {
 	    int lambda =  ((stats->IPGsum > 0.0) ? (round (stats->cntIPG / stats->IPGsum)) : 0.0);
 	    double variance = (stats->transit.current.cnt < 2) ? 0 : \
 		(sqrt(stats->transit.current.m2 / (stats->transit.current.cnt - 1)));
-	    set_llawbuf_udp(lambda, meantransit, variance, stats);
+	    set_llawbuf_udp(lambda, meantransit, variance, stats->cntIPG);
 	    set_netpowerbuf(meantransit, stats);
 	    printf(report_bw_jitter_loss_enhanced_triptime_format, stats->common->transferIDStr,
 		   stats->ts.iStart, stats->ts.iEnd,
@@ -698,7 +778,7 @@ void udp_output_read_enhanced_triptime (struct TransferInfo *stats) {
     _output_outoforder(stats);
     fflush(stdout);
 }
-void udp_output_read_enhanced_triptime_isoch (struct TransferInfo *stats) {
+void udp_output_read_triptime_isoch (struct TransferInfo *stats) {
     HEADING_PRINT_COND(report_bw_jitter_loss_enhanced_isoch_triptime);
     _print_stats_common(stats);
     if (!stats->cntIPG) {
@@ -722,10 +802,8 @@ void udp_output_read_enhanced_triptime_isoch (struct TransferInfo *stats) {
 		   (100.0 * stats->cntError) / stats->cntDatagrams,
 		   (stats->cntIPG / stats->IPGsum));
 	} else {
+	    double frame_meantransit = (stats->isochstats.transit.current.cnt > 0) ? (stats->isochstats.transit.current.sum / stats->isochstats.transit.current.cnt) : 0;
 	    double meantransit = (stats->transit.current.cnt > 0) ? (stats->transit.current.sum / stats->transit.current.cnt) : 0;
-	    int lambda =  ((stats->IPGsum > 0.0) ? (round (stats->cntIPG / stats->IPGsum)) : 0.0);
-	    double variance = (stats->transit.current.cnt < 2) ? 0 : (sqrt(stats->transit.current.m2 / (stats->transit.current.cnt - 1)));
-	    set_llawbuf_udp(lambda, meantransit, variance, stats);
 	    set_netpowerbuf(meantransit, stats);
 	    printf(report_bw_jitter_loss_enhanced_isoch_format, stats->common->transferIDStr,
 		   stats->ts.iStart, stats->ts.iEnd,
@@ -737,9 +815,12 @@ void udp_output_read_enhanced_triptime_isoch (struct TransferInfo *stats) {
 		   stats->transit.current.max * 1e3,
 		   (stats->transit.current.cnt < 2) ? 0 : 1e3 * (sqrt(stats->transit.current.m2 / (stats->transit.current.cnt - 1))),
 		   (stats->cntIPG / stats->IPGsum),
-		   llaw_buf,
-		   netpower_buf,
-		   stats->isochstats.cntFrames, stats->isochstats.cntFramesMissed);
+		   stats->isochstats.cntFrames, stats->isochstats.cntFramesMissed,
+		   (frame_meantransit * 1e3),
+		   stats->isochstats.transit.current.min * 1e3,
+		   stats->isochstats.transit.current.max * 1e3,
+		   (stats->isochstats.transit.current.cnt < 2) ? 0 : 1e3 * (sqrt(stats->isochstats.transit.current.m2 / (stats->isochstats.transit.current.cnt - 1))),
+		   netpower_buf);
 	}
     }
     if (stats->latency_histogram) {
@@ -1269,7 +1350,11 @@ static void reporter_output_client_settings (struct ReportSettings *report) {
 	char tmpbuf[40];
 	byte_snprintf(tmpbuf, sizeof(tmpbuf), report->common->BurstSize, 'A');
 	tmpbuf[39]='\0';
-	printf(client_burstperiod, (1.0 / report->common->FPS), tmpbuf);
+	if (report->common->bbcount) {
+	    printf(client_burstperiodcount, tmpbuf, report->common->bbcount, (1.0 / report->common->FPS));
+	} else {
+	    printf(client_burstperiod, tmpbuf, (1.0 / report->common->FPS));
+	}
     }
     if (isBounceBack(report->common)) {
 	char tmpbuf[40];
@@ -1332,11 +1417,12 @@ static void reporter_output_client_settings (struct ReportSettings *report) {
 	if (isWritePrefetch(report->common)) {
 	    fprintf(stdout, "Event based writes (pending queue watermark at %d bytes)\n", report->common->WritePrefetch);
 	}
+#endif
 	if (isHistogram(report->common)) {
-	    fprintf(stdout, "Enabled select histograms bin-width=%0.3f ms, bins=%d\n", \
+	    fprintf(stdout, "Enabled write histograms bin-width=%0.3f ms, bins=%d\n", \
 		((1e3 * report->common->HistBinsize) / pow(10,report->common->HistUnits)), report->common->HistBins);
 	}
-#endif
+
     }
     fflush(stdout);
 }
@@ -1344,7 +1430,7 @@ static void reporter_output_client_settings (struct ReportSettings *report) {
 void reporter_connect_printf_tcp_final (struct ConnectionInfo * report) {
     if (report->connect_times.cnt > 1) {
         double variance = (report->connect_times.cnt < 2) ? 0 : 1e3* (sqrt(report->connect_times.m2 / (report->connect_times.cnt - 1)));
-        fprintf(stdout, "[ CT] final connect times (min/avg/max/stdev) = %0.3f/%0.3f/%0.3f/%0.3f ms (tot/err) = %d/%d\n", \
+        fprintf(stdout, "[ CT] final connect times (min/avg/max/stdev) = %0.3f/%0.3f/%0.3f/%0.3f ms (tot/err) = %" PRIdMAX "/%" PRIdMAX "\n", \
 		report->connect_times.min,  \
 	        (report->connect_times.sum / report->connect_times.cnt), \
 		report->connect_times.max, variance,  \
@@ -1405,7 +1491,11 @@ void reporter_print_connection_report (struct ConnectionInfo *report) {
 	b += strlen(b);
     }
     if (isBounceBack(report->common)) {
-	snprintf(b, SNBUFFERSIZE-strlen(b), " (bb len/hold=%d/%d)", report->common->bbsize, report->common->bbhold);
+	if (isTcpQuickAck(report->common)) {
+	    snprintf(b, SNBUFFERSIZE-strlen(b), " (bb w/quickack len/hold=%d/%d)", report->common->bbsize, report->common->bbhold);
+	} else {
+	    snprintf(b, SNBUFFERSIZE-strlen(b), " (bb len/hold=%d/%d)", report->common->bbsize, report->common->bbhold);
+	}
 	b += strlen(b);
     }
     if (isL2LengthCheck(report->common)) {
@@ -1448,7 +1538,7 @@ void reporter_print_connection_report (struct ConnectionInfo *report) {
 	}
     }
 #if HAVE_DECL_TCP_QUICKACK
-    if (isTcpQuickAck(report->common)) {
+    if (isTcpQuickAck(report->common) && !isBounceBack(report->common)) {
 	snprintf(b, SNBUFFERSIZE-strlen(b), " (qack)");
 	b += strlen(b);
     }
@@ -1633,10 +1723,10 @@ void reporter_peerversion (struct ConnectionInfo *report, uint32_t upper, uint32
 
 void reporter_print_server_relay_report (struct ServerRelay *report) {
     printf(server_reporting, report->info.common->transferID);
-    if (!isEnhanced(report->info.common)) {
-	udp_output_read(&report->info);
+    if (isTripTime(report->info.common) || isEnhanced(report->info.common)) {
+	udp_output_read_triptime(&report->info);
     } else {
-	udp_output_read_enhanced_triptime(&report->info);
+	udp_output_read(&report->info);
     }
     fflush(stdout);
 }
