@@ -1,3 +1,4 @@
+
 /*---------------------------------------------------------------
  * Copyright (c) 1999,2000,2001,2002,2003
  * The Board of Trustees of the University of Illinois
@@ -90,6 +91,8 @@ static void reporter_reset_mmm (struct MeanMinMaxStats *stats);
 
 // one way delay (OWD) calculations
 static void reporter_handle_packet_oneway_transit(struct TransferInfo *stats, struct ReportStruct *packet);
+static void reporter_handle_isoch_oneway_transit_tcp(struct TransferInfo *stats, struct ReportStruct *packet);
+static void reporter_handle_isoch_oneway_transit_udp(struct TransferInfo *stats, struct ReportStruct *packet);
 static void reporter_handle_frame_isoch_oneway_transit(struct TransferInfo *stats, struct ReportStruct *packet);
 static void reporter_handle_txmsg_oneway_transit(struct TransferInfo *stats, struct ReportStruct *packet);
 static void reporter_handle_rxmsg_oneway_transit(struct TransferInfo *stats, struct ReportStruct *packet);
@@ -420,7 +423,9 @@ void reporter_spawn (struct thread_Settings *thread) {
 #ifdef HAVE_THREAD_DEBUG
     thread_debug( "Reporter thread started");
 #endif
-    myConnectionReport = InitConnectOnlyReport(thread);
+    if (isEnhanced(thread)) {
+        myConnectionReport = InitConnectOnlyReport(thread);
+    }
     /*
      * reporter main loop needs to wait on all threads being started
      */
@@ -708,6 +713,128 @@ static void reporter_handle_packet_oneway_transit (struct TransferInfo *stats, s
     stats->transit.current.last = transit;
 }
 
+
+static void reporter_handle_isoch_oneway_transit_tcp (struct TransferInfo *stats, struct ReportStruct *packet) {
+    // printf("fid=%lu bs=%lu remain=%lu\n", packet->frameID, packet->burstsize, packet->remaining);
+    if (packet->frameID && packet->transit_ready) {
+	int framedelta = 0;
+	double frametransit = 0;
+	// very first isochronous frame
+	if (!stats->isochstats.frameID) {
+	    stats->isochstats.framecnt.current=packet->frameID;
+	}
+	// perform client and server frame based accounting
+	if ((framedelta = (packet->frameID - stats->isochstats.frameID))) {
+	    stats->isochstats.framecnt.current++;
+	    if (framedelta > 1) {
+		stats->isochstats.framelostcnt.current += (framedelta-1);
+		stats->isochstats.slipcnt.current++;
+	    } else if (stats->common->ThreadMode == kMode_Server) {
+		// Triptimes use the frame start time in passed in the frame header while
+		// it's calculated from the very first start time and frame id w/o trip timees
+		if (isTripTime(stats->common)) {
+		    frametransit = TimeDifference(packet->packetTime, packet->isochStartTime);
+		} else {
+		    frametransit = TimeDifference(packet->packetTime, packet->isochStartTime) \
+			- ((packet->burstperiod * (packet->frameID - 1)) / 1e6);
+		}
+		reporter_update_mmm(&stats->isochstats.transit.total, frametransit);
+		reporter_update_mmm(&stats->isochstats.transit.current, frametransit);
+		if (stats->framelatency_histogram) {
+		    histogram_insert(stats->framelatency_histogram, frametransit, &packet->packetTime);
+		}
+	    }
+	}
+	stats->isochstats.frameID = packet->frameID;
+    }
+}
+
+static void reporter_handle_isoch_oneway_transit_udp (struct TransferInfo *stats, struct ReportStruct *packet) {
+    // printf("fid=%lu bs=%lu remain=%lu\n", packet->frameID, packet->burstsize, packet->remaining);
+    if (packet->frameID && packet->transit_ready) {
+	int framedelta = 0;
+	double frametransit = 0;
+	// very first isochronous frame
+	if (!stats->isochstats.frameID) {
+	    stats->isochstats.framecnt.current=1;
+	}
+	// perform client and server frame based accounting
+	framedelta = (packet->frameID - stats->isochstats.frameID);
+	stats->isochstats.framecnt.current++;
+//      stats->matchframeID = packet->frameID + 1;
+	if (framedelta == 1) {
+	    // Triptimes use the frame start time in passed in the frame header while
+	    // it's calculated from the very first start time and frame id w/o trip timees
+	    frametransit = TimeDifference(packet->packetTime, packet->isochStartTime) \
+		- ((packet->burstperiod * (packet->frameID - 1)) / 1e6);
+	    reporter_update_mmm(&stats->isochstats.transit.total, frametransit);
+	    reporter_update_mmm(&stats->isochstats.transit.current, frametransit);
+	    if (stats->framelatency_histogram) {
+		histogram_insert(stats->framelatency_histogram, frametransit, &packet->packetTime);
+	    }
+	} else {
+	    if (stats->common->ThreadMode == kMode_Server) {
+		stats->isochstats.framelostcnt.current += framedelta;
+	    } else {
+		stats->isochstats.framelostcnt.current += framedelta;
+		stats->isochstats.slipcnt.current++;
+	    }
+	}
+	stats->isochstats.frameID = packet->frameID;
+    }
+}
+
+
+static void reporter_handle_rxmsg_oneway_transit (struct TransferInfo *stats, struct ReportStruct *packet) {
+    // very first burst
+    if (!stats->isochstats.frameID) {
+	stats->isochstats.frameID = packet->frameID;
+    }
+    if (packet->frameID && packet->transit_ready) {
+	double transit = TimeDifference(packet->packetTime, packet->sentTime);
+//	printf("**** r pt %ld.%ld st %ld.%ld %f\n", packet->packetTime.tv_sec, packet->packetTime.tv_usec, packet->sentTime.tv_sec, packet->sentTime.tv_usec, transit);
+	reporter_update_mmm(&stats->transit.total, transit);
+	reporter_update_mmm(&stats->transit.current, transit);
+	if (stats->framelatency_histogram) {
+	    histogram_insert(stats->framelatency_histogram, transit, &packet->sentTime);
+	}
+	if (!TimeZero(stats->ts.prevpacketTime)) {
+	    double delta = TimeDifference(packet->sentTime, stats->ts.prevpacketTime);
+	    stats->IPGsum += delta;
+	}
+	stats->ts.prevpacketTime = packet->sentTime;
+	stats->isochstats.frameID++;  // RJM fix this overload
+	stats->burstid_transition = true;
+    } else if (stats->burstid_transition && packet->frameID && (packet->frameID != stats->isochstats.frameID)) {
+	stats->burstid_transition = false;
+	fprintf(stderr,"%sError: expected burst id %u but got %" PRIdMAX "\n", \
+		stats->common->transferIDStr, stats->isochstats.frameID + 1, packet->frameID);
+	stats->isochstats.frameID = packet->frameID;
+    }
+}
+
+static inline void reporter_handle_txmsg_oneway_transit (struct TransferInfo *stats, struct ReportStruct *packet) {
+    // very first burst
+    if (!stats->isochstats.frameID) {
+	stats->isochstats.frameID = packet->frameID;
+    }
+    if (!TimeZero(stats->ts.prevpacketTime)) {
+	double delta = TimeDifference(packet->sentTime, stats->ts.prevpacketTime);
+	stats->IPGsum += delta;
+    }
+    if (packet->transit_ready) {
+        reporter_handle_packet_oneway_transit(stats, packet);
+	// printf("***Burst id = %ld, transit = %f\n", packet->frameID, stats->transit.lastTransit);
+	if (isIsochronous(stats->common)) {
+	    if (packet->frameID && (packet->frameID != (stats->isochstats.frameID + 1))) {
+		fprintf(stderr,"%sError: expected burst id %u but got %" PRIdMAX "\n", \
+			stats->common->transferIDStr, stats->isochstats.frameID + 1, packet->frameID);
+	    }
+	    stats->isochstats.frameID = packet->frameID;
+	}
+    }
+}
+
 static void reporter_handle_frame_isoch_oneway_transit (struct TransferInfo *stats, struct ReportStruct *packet) {
     // printf("fid=%lu bs=%lu remain=%lu\n", packet->frameID, packet->burstsize, packet->remaining);
     if (packet->frameID && packet->transit_ready) {
@@ -747,57 +874,7 @@ static void reporter_handle_frame_isoch_oneway_transit (struct TransferInfo *sta
     }
 }
 
-static void reporter_handle_rxmsg_oneway_transit (struct TransferInfo *stats, struct ReportStruct *packet) {
-    // very first burst
-    if (!stats->isochstats.frameID) {
-	stats->isochstats.frameID = packet->frameID;
-    }
-    if (packet->frameID && packet->transit_ready) {
-	double transit = TimeDifference(packet->packetTime, packet->sentTime);
-	reporter_update_mmm(&stats->transit.total, transit);
-	reporter_update_mmm(&stats->transit.current, transit);
-	if (stats->framelatency_histogram) {
-	    histogram_insert(stats->framelatency_histogram, transit, &packet->sentTime);
-	}
-	if (!TimeZero(stats->ts.prevpacketTime)) {
-	    double delta = TimeDifference(packet->sentTime, stats->ts.prevpacketTime);
-	    stats->IPGsum += delta;
-	}
-	stats->ts.prevpacketTime = packet->sentTime;
-	stats->isochstats.frameID++;  // RJM fix this overload
-	stats->burstid_transition = true;
-	// printf("***Burst id = %ld, transit = %f\n", packet->frameID, stats->transit.lastTransit);
-    } else if (stats->burstid_transition && packet->frameID && (packet->frameID != stats->isochstats.frameID)) {
-	stats->burstid_transition = false;
-	fprintf(stderr,"%sError: expected burst id %u but got %" PRIdMAX "\n", \
-		stats->common->transferIDStr, stats->isochstats.frameID + 1, packet->frameID);
-	stats->isochstats.frameID = packet->frameID;
-    }
-}
-
-static inline void reporter_handle_txmsg_oneway_transit (struct TransferInfo *stats, struct ReportStruct *packet) {
-    // very first burst
-    if (!stats->isochstats.frameID) {
-	stats->isochstats.frameID = packet->frameID;
-    }
-    if (!TimeZero(stats->ts.prevpacketTime)) {
-	double delta = TimeDifference(packet->sentTime, stats->ts.prevpacketTime);
-	stats->IPGsum += delta;
-    }
-    if (packet->transit_ready) {
-        reporter_handle_packet_oneway_transit(stats, packet);
-	// printf("***Burst id = %ld, transit = %f\n", packet->frameID, stats->transit.lastTransit);
-	if (isIsochronous(stats->common)) {
-	    if (packet->frameID && (packet->frameID != (stats->isochstats.frameID + 1))) {
-		fprintf(stderr,"%sError: expected burst id %u but got %" PRIdMAX "\n", \
-			stats->common->transferIDStr, stats->isochstats.frameID + 1, packet->frameID);
-	    }
-	    stats->isochstats.frameID = packet->frameID;
-	}
-    }
-}
 // This is done in reporter thread context
-
 void reporter_handle_packet_client (struct ReporterData *data, struct ReportStruct *packet) {
     struct TransferInfo *stats = &data->info;
     stats->ts.packetTime = packet->packetTime;
@@ -816,10 +893,10 @@ void reporter_handle_packet_client (struct ReporterData *data, struct ReportStru
 	    reporter_handle_txmsg_oneway_transit(stats, packet);
 	}
 	if (isTcpWriteTimes(stats->common) && !isUDP(stats->common) && (packet->write_time > 0)) {
-	    reporter_update_mmm(&stats->write_mmm.current, (double) packet->write_time);
-	    reporter_update_mmm(&stats->write_mmm.total, (double) packet->write_time);
+	    reporter_update_mmm(&stats->write_mmm.current, ((double) packet->write_time));
+	    reporter_update_mmm(&stats->write_mmm.total, ((double) packet->write_time));
 	    if (stats->write_histogram ) {
-		histogram_insert(stats->write_histogram, (1e-6 * packet->write_time), &packet->packetTime);
+		histogram_insert(stats->write_histogram, (1e-6 * packet->write_time), NULL);
 	    }
 	}
     }
@@ -836,18 +913,20 @@ void reporter_handle_packet_client (struct ReporterData *data, struct ReportStru
 }
 
 void reporter_handle_packet_bb_client (struct ReporterData *data, struct ReportStruct *packet) {
-    struct TransferInfo *stats = &data->info;
-    stats->ts.packetTime = packet->packetTime;
     if (!packet->emptyreport && (packet->packetLen > 0)) {
+        struct TransferInfo *stats = &data->info;
 	stats->total.Bytes.current += packet->packetLen;
 	double bbrtt = TimeDifference(packet->packetTime, packet->sentTime);
 	double bbowdto = TimeDifference(packet->sentTimeRX, packet->sentTime);
 	double bbowdfro = TimeDifference(packet->packetTime, packet->sentTimeTX);
 	double asym = bbowdfro - bbowdto;
+	stats->ts.prevpacketTime = packet->packetTime;
 #if 0
-	fprintf(stderr, "BB Debug: ctx=%lx.%lx srx=%lx.%lx stx=%lx.%lx crx=%lx.%lx\n", packet->sentTime.tv_sec, packet->sentTime.tv_usec, packet->sentTimeRX.tv_sec, packet->sentTimeRX.tv_usec, packet->sentTimeTX.tv_sec, packet->sentTimeTX.tv_usec, packet->packetTime.tv_sec, packet->packetTime.tv_usec);
+	fprintf(stderr, "BB Debug: ctx=%lx.%lx srx=%lx.%lx stx=%lx.%lx crx=%lx.%lx\n", packet->sentTime.tv_sec, packet->sentTime.tv_usec, packet->sentTimeRX.tv_sec, packet->sentTimeRX.tv_usec, packet->sentTimeTX.tv_sec, packet->sentTimeTX.tv_usec, packet->packetTime.tv_sec, packet->pAckettime.tv_usec);
 	fprintf(stderr, "BB Debug: ctx=%ld.%ld srx=%ld.%ld stx=%ld.%ld crx=%ld.%ld\n", packet->sentTime.tv_sec, packet->sentTime.tv_usec, packet->sentTimeRX.tv_sec, packet->sentTimeRX.tv_usec, packet->sentTimeTX.tv_sec, packet->sentTimeTX.tv_usec, packet->packetTime.tv_sec, packet->packetTime.tv_usec);
 #endif
+	stats->iBBrunning += bbrtt;
+	stats->fBBrunning += bbrtt;
 	reporter_update_mmm(&stats->bbrtt.current, bbrtt);
 	reporter_update_mmm(&stats->bbrtt.total, bbrtt);
 	reporter_update_mmm(&stats->bbowdto.total, bbowdto);
@@ -882,7 +961,7 @@ inline void reporter_handle_packet_server_tcp (struct ReporterData *data, struct
 	}
 	if (packet->transit_ready) {
 	    if (isIsochronous(stats->common) && packet->frameID) {
-		reporter_handle_frame_isoch_oneway_transit(stats, packet);
+		reporter_handle_isoch_oneway_transit_tcp(stats, packet);
 	    } else if (isPeriodicBurst(stats->common) || isTripTime(stats->common)) {
 		reporter_handle_rxmsg_oneway_transit(stats, packet);
 	    }
@@ -933,10 +1012,10 @@ inline void reporter_handle_packet_server_udp (struct ReporterData *data, struct
 	}
 	reporter_compute_packet_pps(stats, packet);
 	reporter_handle_packet_oneway_transit(stats, packet);
-	if (packet->transit_ready) {
-	    if (isIsochronous(stats->common) && packet->frameID) {
-		reporter_handle_frame_isoch_oneway_transit(stats, packet);
-	    } else if (isPeriodicBurst(stats->common) && packet->frameID) {
+	if (packet->transit_ready && packet->frameID) {
+	    if (isIsochronous(stats->common)) {
+		reporter_handle_isoch_oneway_transit_udp(stats, packet);
+	    } else if (isPeriodicBurst(stats->common)) {
 		reporter_handle_txmsg_oneway_transit(stats, packet);
 	    }
 	}
@@ -1023,6 +1102,7 @@ static inline void reporter_reset_transfer_stats_client_tcp (struct TransferInfo
     stats->sock_callstats.write.tcpstats.retry = 0;
 #endif
     if (isBounceBack(stats->common)) {
+	stats->iBBrunning = 0;
 	reporter_reset_mmm(&stats->bbrtt.current);
 	reporter_reset_mmm(&stats->bbowdto.current);
 	reporter_reset_mmm(&stats->bbowdfro.current);
@@ -1506,6 +1586,7 @@ void reporter_transfer_protocol_sum_client_tcp (struct TransferInfo *stats, int
 
 void reporter_transfer_protocol_client_bb_tcp (struct ReporterData *data, int final) {
     struct TransferInfo *stats = &data->info;
+
     if (final) {
 	if ((stats->cntBytes > 0) && stats->output_handler && !TimeZero(stats->ts.intervalTime)) {
 	    // print a partial interval report if enable and this a final
@@ -1523,13 +1604,13 @@ void reporter_transfer_protocol_client_bb_tcp (struct ReporterData *data, int fi
 	reporter_set_timestamps_time(&stats->ts, TOTAL);
 	stats->final=1;
     } else {
-	stats->final=0;
 	stats->cntBytes = stats->total.Bytes.current - stats->total.Bytes.prev;
     }
     if ((stats->output_handler) && !(stats->isMaskOutput))
-	(*stats->output_handler)(stats);
-    if (!final)
+        (*stats->output_handler)(stats);
+    if (!final) {
 	reporter_reset_transfer_stats_client_tcp(stats);
+    }
 }
 
 void reporter_transfer_protocol_server_bb_tcp (struct ReporterData *data, int final) {
@@ -1545,6 +1626,7 @@ void reporter_transfer_protocol_server_bb_tcp (struct ReporterData *data, int fi
 	    }
         }
 #if HAVE_TCP_STATS
+
 	stats->sock_callstats.write.tcpstats.retry = stats->sock_callstats.write.tcpstats.retry_tot;
 #endif
 	stats->cntBytes = stats->total.Bytes.current;
@@ -1651,6 +1733,7 @@ int reporter_condprint_time_interval_report (struct ReporterData *data, struct R
     // Print a report if packet time exceeds the next report interval time,
     // Also signal to the caller to move to the next report (or packet ring)
     // if there was output. This will allow for more precise interval sum accounting.
+    // printf("***** pt = %ld.%ld next = %ld.%ld\n", packet->packetTime.tv_sec, packet->packetTime.tv_usec, stats->ts.nextTime.tv_sec, stats->ts.nextTime.tv_usec);
     if (TimeDifference(stats->ts.nextTime, packet->packetTime) < 0) {
 	assert(data->transfer_protocol_handler!=NULL);
 	advance_jobq = 1;
@@ -1741,7 +1824,6 @@ int reporter_condprint_burst_interval_report_server_tcp (struct ReporterData *da
 }
 
 int reporter_condprint_burst_interval_report_client_tcp (struct ReporterData *data, struct ReportStruct *packet) {
-
     struct TransferInfo *stats = &data->info;
     int advance_jobq = 0;
     // first packet of a burst and not a duplicate
