@@ -136,6 +136,7 @@ static void common_copy (struct ReportCommon **common, struct thread_Settings *i
     (*common)->RTOS = inSettings->mRTOS;
     (*common)->bbsize = inSettings->mBounceBackBytes;
     (*common)->bbhold = inSettings->mBounceBackHold;
+    (*common)->bbcount = inSettings->mBounceBackBurst;
 #if HAVE_DECL_TCP_WINDOW_CLAMP
     (*common)->ClampSize = inSettings->mClampSize;
 #endif
@@ -143,7 +144,7 @@ static void common_copy (struct ReportCommon **common, struct thread_Settings *i
     (*common)->WritePrefetch = inSettings->mWritePrefetch;
 #endif
 #ifdef HAVE_THREAD_DEBUG
-    thread_debug("Alloc common rpt/com/size/strsz %p/%p/%d/%d", (void *) common, (void *)(*common), sizeof(struct ReportCommon), bytecnt);
+    thread_debug("Alloc common rpt/com/size %p/%p/%d", (void *) common, (void *)(*common), sizeof(struct ReportCommon));
 #endif
 }
 
@@ -546,11 +547,11 @@ struct ReportHeader* InitIndividualReport (struct thread_Settings *inSettings) {
 		    ireport->info.output_handler = NULL;
 		} else if (isTripTime(inSettings)) {
 		    if (isIsochronous(inSettings))
-			ireport->info.output_handler = udp_output_read_enhanced_triptime_isoch;
+			ireport->info.output_handler = udp_output_read_triptime_isoch;
 		    else
-			ireport->info.output_handler = udp_output_read_enhanced_triptime;
+			ireport->info.output_handler = udp_output_read_triptime;
 		} else if (isEnhanced(inSettings)) {
-		    ireport->info.output_handler = udp_output_read_enhanced_triptime;
+		    ireport->info.output_handler = udp_output_read_triptime;
 		} else if (isFullDuplex(inSettings)) {
 		    ireport->info.output_handler = udp_output_read;
 		} else {
@@ -578,8 +579,10 @@ struct ReportHeader* InitIndividualReport (struct thread_Settings *inSettings) {
 		ireport->info.output_handler = tcp_output_write;
 	    } else if (isSumOnly(inSettings)) {
 		ireport->info.output_handler = NULL;
+	    } else if (isTripTime(inSettings) && isIsochronous(inSettings)) {
+		ireport->info.output_handler = tcp_output_read_enhanced_isoch;
 	    } else if (isTripTime(inSettings)) {
-		ireport->info.output_handler = tcp_output_read_enhanced_triptime;
+		ireport->info.output_handler = tcp_output_read_triptime;
 	    } else if (isEnhanced(inSettings)) {
 		ireport->info.output_handler = tcp_output_read_enhanced;
 	    } else if (!isFullDuplex(inSettings)) {
@@ -653,24 +656,19 @@ struct ReportHeader* InitIndividualReport (struct thread_Settings *inSettings) {
 								   inSettings->mHistci_upper, ireport->info.common->transferID, name);
 	}
     }
-#if HAVE_DECL_TCP_NOTSENT_LOWAT
-    if ((inSettings->mThreadMode == kMode_Client) && isWritePrefetch(inSettings) && !isUDP(inSettings) && isHistogram(inSettings)) {
-	char name[] = "S8";
-	ireport->info.latency_histogram =  histogram_init(inSettings->mHistBins,inSettings->mHistBinsize,0,\
-							  pow(10,inSettings->mHistUnits), \
-							  inSettings->mHistci_lower, inSettings->mHistci_upper, ireport->info.common->transferID, name);
-    } else if ((inSettings->mThreadMode == kMode_Client) && isTcpWriteTimes(inSettings) && isHistogram(inSettings) && !isUDP(inSettings)) {
-	char name[] = "W8";
-	inSettings->mHistBins = 100000; // 10 seconds wide
-	inSettings->mHistBinsize = 100; // 100 usec bins
-	inSettings->mHistUnits = 6;  // usecs 10 pow(x)
-	inSettings->mHistci_lower = 5;
-	inSettings->mHistci_upper = 95;
-	ireport->info.write_histogram =  histogram_init(inSettings->mHistBins,inSettings->mHistBinsize,0,	\
-							pow(10,inSettings->mHistUnits), \
-							inSettings->mHistci_lower, inSettings->mHistci_upper, ireport->info.common->transferID, name);
+    if ((inSettings->mThreadMode == kMode_Client) && !isUDP(inSettings) && isHistogram(inSettings)) {
+	if (isTcpWriteTimes(inSettings)) {
+	    char name[] = "W8";
+	    ireport->info.write_histogram =  histogram_init(inSettings->mHistBins,inSettings->mHistBinsize,0,\
+							    pow(10,inSettings->mHistUnits), \
+							    inSettings->mHistci_lower, inSettings->mHistci_upper, ireport->info.common->transferID, name);
+	} else if (isWritePrefetch(inSettings)) {
+	    char name[] = "S8";
+	    ireport->info.latency_histogram =  histogram_init(inSettings->mHistBins,inSettings->mHistBinsize,0,\
+							      pow(10,inSettings->mHistUnits), \
+							      inSettings->mHistci_lower, inSettings->mHistci_upper, ireport->info.common->transferID, name);
+	}
     }
-#endif
     if ((inSettings->mThreadMode == kMode_Client) && isBounceBack(inSettings)) {
 	char name[] = "BB8";
 	inSettings->mHistBins = 100000; // 10 seconds wide
