@@ -144,7 +144,7 @@ inline bool Server::InProgress () {
 void Server::RunTCP () {
     long currLen;
     intmax_t totLen = 0;
-    struct TCP_burst_payload burst_info;
+    struct TCP_burst_payload burst_info; // used to store burst header and report in last packet of burst
     Timestamp time1, time2;
     double tokens=0.000004;
 
@@ -154,7 +154,7 @@ void Server::RunTCP () {
 
     int burst_nleft = 0;
     burst_info.burst_id = 0;
-
+    burst_info.burst_period_us = 0;
     burst_info.send_tt.write_tv_sec = 0;
     burst_info.send_tt.write_tv_usec = 0;
     now.setnow();
@@ -190,6 +190,7 @@ void Server::RunTCP () {
 		if ((n = recvn(mSettings->mSock, reinterpret_cast<char *>(&burst_info), sizeof(struct TCP_burst_payload), 0)) == sizeof(struct TCP_burst_payload)) {
 		    // burst_info.typelen.type = ntohl(burst_info.typelen.type);
 		    // burst_info.typelen.length = ntohl(burst_info.typelen.length);
+		    // This is the first stamp of the burst
 		    burst_info.flags = ntohl(burst_info.flags);
 		    burst_info.burst_size = ntohl(burst_info.burst_size);
 		    assert(burst_info.burst_size > 0);
@@ -197,19 +198,23 @@ void Server::RunTCP () {
 		    burst_info.burst_id = ntohl(burst_info.burst_id);
 		    reportstruct->frameID = burst_info.burst_id;
 		    if (isTripTime(mSettings)) {
-			reportstruct->sentTime.tv_sec = ntohl(burst_info.send_tt.write_tv_sec);
-			reportstruct->sentTime.tv_usec = ntohl(burst_info.send_tt.write_tv_usec);
+			burst_info.send_tt.write_tv_sec = ntohl(burst_info.send_tt.write_tv_sec);
+			burst_info.send_tt.write_tv_usec = ntohl(burst_info.send_tt.write_tv_usec);
+		    } else if (isIsochronous(mSettings)) {
+			burst_info.send_tt.write_tv_sec = (uint32_t)myReport->info.ts.startTime.tv_sec;
+			burst_info.send_tt.write_tv_usec = (uint32_t)myReport->info.ts.startTime.tv_usec;
+			burst_info.burst_period_us = ntohl(burst_info.burst_period_us);
 		    } else {
-			now.setnow();
-			reportstruct->sentTime.tv_sec = now.getSecs();
-			reportstruct->sentTime.tv_usec = now.getUsecs();
+			fprintf(stderr, "Program error in server per burst");
 		    }
-		    // This is the first stamp of the burst
+		    reportstruct->sentTime.tv_sec = burst_info.send_tt.write_tv_sec;
+		    reportstruct->sentTime.tv_usec = burst_info.send_tt.write_tv_usec;
 		    myReport->info.ts.prevsendTime = reportstruct->sentTime;
 		    burst_nleft = burst_info.burst_size - n;
 		    if (burst_nleft == 0) {
 			reportstruct->prevSentTime = myReport->info.ts.prevsendTime;
 			reportstruct->transit_ready = 1;
+			reportstruct->burstperiod = burst_info.burst_period_us;
 		    }
 		    currLen += n;
 		    readLen = (mSettings->mBufLen < burst_nleft) ? mSettings->mBufLen : burst_nleft;
@@ -234,7 +239,12 @@ void Server::RunTCP () {
 		    if (isburst) {
 			burst_nleft -= n;
 			if (burst_nleft == 0) {
-			    reportstruct->prevSentTime = myReport->info.ts.prevsendTime;
+			    reportstruct->sentTime = myReport->info.ts.prevsendTime;
+			    if (isTripTime(mSettings) || isIsochronous(mSettings)) {
+				reportstruct->isochStartTime.tv_sec = burst_info.send_tt.write_tv_sec;
+				reportstruct->isochStartTime.tv_usec = burst_info.send_tt.write_tv_usec;
+				reportstruct->burstperiod = burst_info.burst_period_us;
+			    }
 			    reportstruct->transit_ready = 1;
 			}
 		    }
@@ -288,25 +298,49 @@ void Server::RunTCP () {
     FreeReport(myJob);
 }
 
+void Server::PostNullEvent () {
+    assert(myReport!=NULL);
+    // push a nonevent into the packet ring
+    // this will cause the reporter to process
+    // up to this event
+    memset(reportstruct, 0, sizeof(struct ReportStruct));
+    now.setnow();
+    reportstruct->packetTime.tv_sec = now.getSecs();
+    reportstruct->packetTime.tv_usec = now.getUsecs();
+    reportstruct->emptyreport=1;
+    ReportPacket(myReport, reportstruct);
+}
+
 inline bool Server::ReadBBWithRXTimestamp () {
     bool rc = false;
     int n;
-    if ((n = recvn(mySocket, mSettings->mBuf, mSettings->mBounceBackBytes, 0)) == mSettings->mBounceBackBytes) {
-	struct bounceback_hdr *bbhdr = reinterpret_cast<struct bounceback_hdr *>(mSettings->mBuf);
-	now.setnow();
-	reportstruct->packetTime.tv_sec = now.getSecs();
-	reportstruct->packetTime.tv_usec = now.getUsecs();
-	reportstruct->emptyreport=0;
-	reportstruct->packetLen = mSettings->mBounceBackBytes;
-	// write the rx timestamp back into the payload
-	bbhdr->bbserverRx_ts.sec = htonl(reportstruct->packetTime.tv_sec);
-	bbhdr->bbserverRx_ts.usec = htonl(reportstruct->packetTime.tv_usec);
-	reportstruct->packetLen = mSettings->mBounceBackBytes;
-	rc = true;
-    } else if (n==0) {
-	peerclose = true;
-    } else {
-	reportstruct->emptyreport=1;
+    while (1) {
+	if ((n = recvn(mySocket, mSettings->mBuf, mSettings->mBounceBackBytes, 0)) == mSettings->mBounceBackBytes) {
+	    struct bounceback_hdr *bbhdr = reinterpret_cast<struct bounceback_hdr *>(mSettings->mBuf);
+	    uint16_t bbflags = ntohs(bbhdr->bbflags);
+	    if (!(bbflags & HEADER_BBSTOP)) {
+		now.setnow();
+		reportstruct->packetTime.tv_sec = now.getSecs();
+		reportstruct->packetTime.tv_usec = now.getUsecs();
+		reportstruct->emptyreport=0;
+		reportstruct->packetLen = mSettings->mBounceBackBytes;
+		// write the rx timestamp back into the payload
+		bbhdr->bbserverRx_ts.sec = htonl(reportstruct->packetTime.tv_sec);
+		bbhdr->bbserverRx_ts.usec = htonl(reportstruct->packetTime.tv_usec);
+		ReportPacket(myReport, reportstruct);
+		rc = true;
+	    } else {
+		peerclose = true;
+	    }
+	    break;
+	} else if (n==0) {
+	    peerclose = true;
+	    break;
+	} else if (n == -2){
+	    PostNullEvent();
+	} else {
+	    break;
+	}
     }
     return rc;
 }
@@ -327,15 +361,20 @@ void Server::RunBounceBackTCP () {
     if (mSettings->mInterval && (mSettings->mIntervalMode == kInterval_Time)) {
 	int sotimer = static_cast<int>(round(mSettings->mInterval / 2.0));
 	SetSocketOptionsSendTimeout(mSettings, sotimer);
+	SetSocketOptionsReceiveTimeout(mSettings, sotimer);
     } else if (isModeTime(mSettings)) {
 	int sotimer = static_cast<int>(round(mSettings->mAmount * 10000) / 2);
 	SetSocketOptionsSendTimeout(mSettings, sotimer);
+	SetSocketOptionsReceiveTimeout(mSettings, sotimer);
     }
     myReport->info.ts.prevsendTime = myReport->info.ts.startTime;
     now.setnow();
     reportstruct->packetTime.tv_sec = now.getSecs();
     reportstruct->packetTime.tv_usec = now.getUsecs();
     reportstruct->packetLen = mSettings->mBounceBackBytes;
+    reportstruct->emptyreport=0;
+    ReportPacket(myReport, reportstruct);
+
     while (InProgress()) {
 	int n;
 	reportstruct->emptyreport=1;
@@ -361,7 +400,7 @@ void Server::RunBounceBackTCP () {
 	    }
 	    if ((n = writen(mySocket, mSettings->mBuf, mSettings->mBounceBackBytes, &reportstruct->writecnt)) == mSettings->mBounceBackBytes) {
 		reportstruct->emptyreport=0;
-		reportstruct->packetLen += n;
+		reportstruct->packetLen = n;
 		ReportPacket(myReport, reportstruct);
 	    } else {
 		break;
@@ -452,7 +491,7 @@ inline void Server::SetReportStartTime () {
 	Mutex_Lock(&myReport->GroupSumReport->reference.lock);
 	if (TimeZero(sumstats->ts.startTime)) {
 	    sumstats->ts.startTime = myReport->info.ts.startTime;
-	    if (isModeTime(mSettings)) {
+	    if (isModeTime(mSettings) || isModeInfinite(mSettings)) {
 		sumstats->ts.nextTime = myReport->info.ts.nextTime;
 	    }
 	}
@@ -799,6 +838,7 @@ int Server::L2_quintuple_filter () {
 }
 
 inline void Server::udp_isoch_processing (int rxlen) {
+    reportstruct->transit_ready = 0;
     // Ignore runt sized isoch packets
     if (rxlen < static_cast<int>(sizeof(struct UDP_datagram) +  sizeof(struct client_hdr_v1) + sizeof(struct client_hdrext) + sizeof(struct isoch_payload))) {
 	reportstruct->burstsize = 0;
